==> cupertino_ffi-0.1.5.tar.gz: lib/src/core_foundation/allocator.dart <==
// Copyright (c) 2019 cupertino_ffi authors.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
// OR OTHER DEALINGS IN THE SOFTWARE.

import 'dart:ffi';

import 'package:cupertino_ffi/core_foundation.dart';

final _CFAllocatorGetDefault = dlForCoreFoundation
    .lookupFunction<_CFAllocatorGetDefault_C, _CFAllocatorGetDefault_Dart>(
  "CFAllocatorGetDefault",
);

final Pointer<CFAllocator> _default = _CFAllocatorGetDefault();

typedef _CFAllocatorGetDefault_C = Pointer<CFAllocator> Function();

typedef _CFAllocatorGetDefault_Dart = Pointer<CFAllocator> Function();

@unsized
class CFAllocator extends Struct<CFAllocator> {
  factory CFAllocator._() {
    throw UnimplementedError();
  }

  static Pointer<CFAllocator> getDefault() => _default;
}

==> cupertino_ffi-0.1.6.tar.gz: lib/src/core_foundation/allocator.dart <==
// Copyright (c) 2019 cupertino_ffi authors.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
// OR OTHER DEALINGS IN THE SOFTWARE.

import 'dart:ffi';

import 'package:cupertino_ffi/core_foundation.dart';

final _CFAllocatorGetDefault = dlForCoreFoundation
    .lookupFunction<_CFAllocatorGetDefault_C, _CFAllocatorGetDefault_Dart>(
  "CFAllocatorGetDefault",
);

final Pointer<CFAllocator> _default = _CFAllocatorGetDefault();

typedef _CFAllocatorGetDefault_C = Pointer<CFAllocator> Function();

typedef _CFAllocatorGetDefault_Dart = Pointer<CFAllocator> Function();

@unsized
class CFAllocator extends Struct {
  factory CFAllocator._() {
    throw UnimplementedError();
  }

  static Pointer<CFAllocator> getDefault() => _default;
}
